# Changelog

<!--next-version-placeholder-->

## v0.20.4 (2021-03-22)
### Fix
* **k8sworker:** Tags ([`b1dfa95`](https://github.com/hpe-container-platform-community/hpecp-python-library/commit/b1dfa957b7bc804983a5bcd0bd0b2e4376c9993d))

## v0.20.3 (2021-03-22)
### Fix
* **k8sworker:** Formatting ([`98ae245`](https://github.com/hpe-container-platform-community/hpecp-python-library/commit/98ae245398e4cc371758123a69172559a7fb48e5))

## v0.20.2 (2021-03-22)
### Fix
* **k8sworker:** Tags ([`21abc58`](https://github.com/hpe-container-platform-community/hpecp-python-library/commit/21abc583d02ae1a058e8143c7262f883df668912))

## v0.20.1 (2021-03-22)
### Fix
* **k8sworker:** Error messager ([`d0eb9fb`](https://github.com/hpe-container-platform-community/hpecp-python-library/commit/d0eb9fb403b9f502f46442d5fe5efae205e0dbaa))

## v0.20.0 (2021-03-19)
### Feature
* **k8sworker:** Add examples ([`8a4a03b`](https://github.com/hpe-container-platform-community/hpecp-python-library/commit/8a4a03b074a9c2f03df036157ed3ae742a8b1fdf))

## v0.19.2 (2021-03-18)
### Fix
* **httpclient:** Add example ([`91d1840`](https://github.com/hpe-container-platform-community/hpecp-python-library/commit/91d1840be5293fb30bc1f28fe288bb30a4bc0cfb))

## v0.19.1 (2021-03-18)
### Fix
* **httpclient:** Json output ([`42c80c9`](https://github.com/hpe-container-platform-community/hpecp-python-library/commit/42c80c999c34a0b90959099defe26cdc6438edf0))

## v0.19.0 (2021-03-15)
### Feature
* **k8scluster:** Add external_groups ([`0dde621`](https://github.com/hpe-container-platform-community/hpecp-python-library/commit/0dde62126a6e23b1143e277bd70372b820a71e55))

## v0.18.2 (2021-03-12)
### Fix
* **k8scluster:** Don't add empty ext id server ([`e89ffaf`](https://github.com/hpe-container-platform-community/hpecp-python-library/commit/e89ffaf9ab2a89f8a96d930c56004a79d004aaee))

## v0.18.1 (2021-03-09)
### Fix
* **tenant:** Quota ([`171f223`](https://github.com/hpe-container-platform-community/hpecp-python-library/commit/171f223d4c0dbdedc206caa5670a45b2810fc530))

## v0.18.0 (2021-03-09)
### Feature
* **tenant:** Ml_project ([`6c1f4d7`](https://github.com/hpe-container-platform-community/hpecp-python-library/commit/6c1f4d729dc943c77beccade3fa5b1cabce39f3a))

## v0.17.0 (2021-03-09)
### Feature
* **k8scluster:** Add external_identity_server ([`54fec45`](https://github.com/hpe-container-platform-community/hpecp-python-library/commit/54fec458397dd59740cd9bf75c3c308334e9b7ed))

## v0.16.1 (2020-11-17)
### Fix
* Fix #266 ([`cf9829c`](https://github.com/hpe-container-platform-community/hpecp-python-library/commit/cf9829c74fc01c8c39a8de3aac7bea7d15d46b3d))

## v0.16.0 (2020-09-30)
### Feature
* Add quotas to create() ([`8504a7a`](https://github.com/hpe-container-platform-community/hpecp-python-library/commit/8504a7a9cb829b2793f7cbc6a1b6fc1ca823503a))
